@@ -16,6 +16,7 @@ from collections import OrderedDict
 from collections.abc import Callable
 import types
 from inspect import isclass
+from functools import lru_cache
 from dataclasses import dataclass, InitVar
 from .parsers.json import JSONContent
 from .converters import encoders, parse_basic
@@ -155,7 +156,25 @@ class ModelMeta(type):
     __aliases__: Dict
     __primary_keys__: List
     # Class-level cache
-    _base_class_cache = {}
+    _base_class_cache = OrderedDict()
+    _MAX_CACHE_SIZE = 512  # size limit
+
+    @classmethod
+    def _cache_get(cls, key):
+        """Get item from cache with LRU behavior."""
+        if key not in cls._base_class_cache:
+            return None
+        value = cls._base_class_cache.pop(key)
+        cls._base_class_cache[key] = value
+        return value
+
+    @classmethod
+    def _cache_set(cls, key, value):
+        """Set item in cache with LRU eviction."""
+        # If cache is full, remove oldest item (first in OrderedDict)
+        if len(cls._base_class_cache) >= cls._MAX_CACHE_SIZE:
+            cls._base_class_cache.popitem(last=False)
+        cls._base_class_cache[key] = value
 
     @staticmethod
     def _initialize_fields(attrs, annotations, strict):
@@ -206,7 +225,7 @@ class ModelMeta(type):
             df.type = _type
 
             # Check for primary_key in field metadata
-            if df.metadata.get("primary_key", False):
+            if df.metadata.get("primary", False) or df.primary_key is True:
                 primary_keys.append(field)
 
             # Cache reflection info so we DON’T need to call
@@ -292,12 +311,20 @@ class ModelMeta(type):
 
     def __new__(cls, name, bases, attrs, **kwargs):  # noqa
         annotations = attrs.get('__annotations__', {})
-        base_key = (tuple(bases), tuple(sorted(annotations.items())))
-        strict = getattr(attrs.get('Meta', Meta), 'strict', False)
+        _strict_ = False
+        cols = OrderedDict()
 
-        if base_key in cls._base_class_cache:
+        # Base class constructor
+        base_key = (name, tuple(bases), tuple(sorted(annotations.items())))
+        with contextlib.suppress(TypeError, AttributeError, KeyError):
+            _strict_ = attrs['Meta'].strict
+
+        # Use LRU get method
+        cached = cls._cache_get(base_key)
+        if cached:
+            # if base_key in cls._base_class_cache:
             # Check the Cache First:
-            cached = cls._base_class_cache[base_key]
+            # cached = cls._base_class_cache[base_key]
             cols = cached['cols'].copy()
             _types = cached['types'].copy()
             _typing_args = cached['_typing_args'].copy()
@@ -305,7 +332,6 @@ class ModelMeta(type):
             primary_keys = cached['primary_keys'].copy()
         else:
             # Compute field from Bases:
-            cols = OrderedDict()
             _types = {}
             _typing_args = {}
             aliases = {}
@@ -325,7 +351,7 @@ class ModelMeta(type):
 
             # Now initialize subclass-specific fields
             new_cols, new_types, new_typing_args, new_aliases, nw_primary_keys = cls._initialize_fields(  # noqa
-                attrs, annotations, strict
+                attrs, annotations, _strict_
             )
 
             # Merge new fields with inherited fields
@@ -336,13 +362,21 @@ class ModelMeta(type):
             primary_keys.extend(nw_primary_keys)
 
             # Store computed results in cache
-            cls._base_class_cache[base_key] = {
+            # cls._base_class_cache[base_key] = {
+            #     'cols': cols.copy(),
+            #     'types': _types.copy(),
+            #     '_typing_args': _typing_args.copy(),
+            #     'aliases': aliases.copy(),
+            #     'primary_keys': primary_keys.copy(),
+            # }
+            cache_entry = {
                 'cols': cols.copy(),
                 'types': _types.copy(),
                 '_typing_args': _typing_args.copy(),
                 'aliases': aliases.copy(),
                 'primary_keys': primary_keys.copy(),
             }
+            cls._cache_set(base_key, cache_entry)
 
         _columns = cols.keys()
         cls.__slots__ = tuple(_columns)
@@ -388,7 +422,7 @@ class ModelMeta(type):
 
         # Now that fields are in attrs, decorate the class as a dataclass
         dc = dataclass(
-            unsafe_hash=strict,
+            unsafe_hash=_strict_,
             repr=False,
             init=True,
             order=False,
@@ -402,7 +436,7 @@ class ModelMeta(type):
         dc.__valid__ = False
         dc.__errors__ = {}
         dc.__values__ = {}
-        dc.__frozen__ = strict
+        dc.__frozen__ = _strict_
         dc.__initialised__ = False
         dc.__field_types__ = _types
         dc.__aliases__ = aliases
